"""Top-level package for Drillcore Transformations."""

__author__ = """Nikolas Ovaskainen"""
__email__ = 'nikolasovaskainen@gmail.com'
__version__ = '0.2.5'
